@@ -1,9 +1,9 @@
 #ifndef GaMaLib___language__header_file_h
 #define GaMaLib___language__header_file_h
 
-namespace GaMaLib {      /* slovnikar 1.03 */
+namespace GaMaLib {      /* slovnikar 1.05 */
 
-enum gama_language { en, cz, fi, du };
+enum gama_language { en, cz, fi, du, hu, ca };
 void set_gama_language(gama_language);
 
 extern const char* T_GKF_bad_angle;
@@ -20,6 +20,7 @@ extern const char* T_GKF_bad_instrument_reflector_height;
 extern const char* T_GKF_bad_network_configuration_unknown_parameter;
 extern const char* T_GKF_bad_orientation_angle;
 extern const char* T_GKF_bad_vector_data;
+extern const char* T_GKF_bad_zangle;
 extern const char* T_GKF_coordinate_x_is_not_defined;
 extern const char* T_GKF_coordinate_y_is_not_defined;
 extern const char* T_GKF_coordinates_without_covariance_matrix;
@@ -186,7 +187,6 @@ extern const char* T_GaMa_resobs_Outlying_observations;
 extern const char* T_GaMa_resobs_Review_of_residuals_analysis_obs;
 extern const char* T_GaMa_resobs_condition_number;
 extern const char* T_GaMa_resobs_header1;
-extern const char* T_GaMa_resobs_header2;
 extern const char* T_GaMa_resobs_mc_critical;
 extern const char* T_GaMa_resobs_mc_max;
 extern const char* T_GaMa_resobs_mc_max_critical;
