@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: network.cpp,v 1.11 2004/02/02 17:07:49 cepek Exp $
+ *  $Id: network.cpp,v 1.15 2004/04/19 18:41:08 cepek Exp $
  */
 
 #include <fstream>
@@ -33,7 +33,7 @@
 #include <gamalib/local/network.h>
 #include <gamalib/local/linearization.h>
 #include <gamalib/itstream.h>
-#include <gamalib/statan.h>
+#include <gnu_gama/statan.h>
 #include <gamalib/skipcomm.h>
 #include <gnu_gama/version.h>
 
@@ -47,8 +47,10 @@ typedef GNU_gama::Cluster<Observation>                  Cluster;
 
 LocalNetwork::LocalNetwork()        
   : pocbod_(0), tst_redbod_(false), pocmer_(0), tst_redmer_(false),
-    m_0_apr_(10), konf_pr_(0.95), tol_abs_(1000), typ_m_0_(empiricka_),
-    tst_rov_opr_(false), tst_vyrovnani_(false), min_n_(0), min_x_(0)
+    m_0_apr_(10), konf_pr_(0.95), tol_abs_(1000), 
+    update_constrained_coordinates_(false), typ_m_0_(empiricka_),
+    tst_rov_opr_(false), tst_vyrovnani_(false), min_n_(0), min_x_(0),
+    gons_(true)
 {
   Asp = 0;
 }
@@ -491,12 +493,12 @@ Double LocalNetwork::conf_int_coef()
   
   Double pravdepodobnost = (1 - konf_pr_)/2;
   if (m_0_apriori())
-    return Normal(pravdepodobnost);
+    return GNU_gama::Normal(pravdepodobnost);
   else if (m_0_aposteriori())
     {
       const int nadb = degrees_of_freedom();
       if ( nadb > 0)
-        return Student(pravdepodobnost, nadb);
+        return GNU_gama::Student(pravdepodobnost, nadb);
       else
         return 0;
     }
@@ -644,6 +646,9 @@ void LocalNetwork::std_error_ellipse(const PointID& cb,
   if (alfa < 0) alfa += M_PI;
 }
 
+// 1.7.09 added optional update of constrained coordinates; inspired
+// by adjustment of photographic observation by Jim Sutherland
+
 void LocalNetwork::refine_approx()
 {
   for (int i=1; i<=sum_unknowns(); i++)
@@ -651,14 +656,14 @@ void LocalNetwork::refine_approx()
       {
         const PointID& cb = unknown_pointid(i);
         LocalPoint& b = PD[cb];
-        if (!b.constrained_xy())
-          b.set_xy(b.x() + x(i)/1000, b.y() + x(i+1)/1000);
+        if (!b.constrained_xy() || update_constrained_coordinates())
+            b.set_xy(b.x() + x(i)/1000, b.y() + x(i+1)/1000);
       }
     else if (unknown_type(i) == 'Z')
       {
         const PointID& cb = unknown_pointid(i);
         LocalPoint& b = PD[cb];
-        if (!b.constrained_z())
+        if (!b.constrained_z() || update_constrained_coordinates())
           b.set_z(b.z() + x(i)/1000);
       }
     else if (unknown_type(i) == 'R')
