@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: network.h,v 1.6 2003/11/06 17:58:57 cepek Exp $
+ *  $Id: network.h,v 1.9 2004/03/30 19:43:07 cepek Exp $
  */
 
 // LocalNetwork - Network Informations class (Informace o siti)
@@ -190,6 +190,15 @@ namespace GaMaLib
       void   apriori_m_0(Double m)  { m_0_apr_ = m; }
       void   tol_abs(Double m)      { tol_abs_ = m; }
       Double tol_abs() const        { return tol_abs_; }
+
+      void   update_constrained_coordinates(bool par)
+      {
+        update_constrained_coordinates_ = par;
+      }
+      bool   update_constrained_coordinates() const
+      {
+        return update_constrained_coordinates_;
+      }
       
       Double stdev_obs(int i) { return sigma_L(i); }
       Double wcoef_res(int i) { return vahkopr(i); }
@@ -242,7 +251,11 @@ namespace GaMaLib
       int maxw_id () const { return 12; } // max width of point id.
       int maxw_unk() const { return  3; } // max width of index of unknown
       int maxw_obs() const { return  4; } // max width of index of observation
-            
+
+      bool gons()    const { return  gons_; }
+      bool degrees() const { return !gons_; }     
+      void set_gons()      { gons_ = true;  Observation::gons = true;  }
+      void set_degrees()   { gons_ = false; Observation::gons = false; }
 
       // #####################################################################
 
@@ -261,15 +274,16 @@ namespace GaMaLib
       
       // parameters of statistical analysis
       
-      Double m_0_apr_;         // a prioti reference standard deviation
+      Double m_0_apr_;         // a priori reference standard deviation
       Double konf_pr_;         // (confidence) probability
       Double tol_abs_;         // tollerance for testing absolute terms
+      bool update_constrained_coordinates_;
       enum ApEm_ { apriorni_, empiricka_ };
       ApEm_ typ_m_0_;          // type of reference standard deviation
       
       bool tst_rov_opr_;       // project equations
       bool vybocujici_abscl_;  // outlying abs. terms in project equations
-      
+
       int pocet_neznamych_;
       
       enum Update { Points, Observations, Residuals, Adjustment };
@@ -299,6 +313,8 @@ namespace GaMaLib
       
       Index  min_n_;           // regularization of free network
       Index* min_x_;
+
+      bool   gons_;
       
       // preparation for design matrix
       
