@@ -1,5 +1,5 @@
 /*  
-    Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
+    Geodesy and Mapping C++ library (GNU GaMa)
     Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
 
     This file is part of the GNU GaMa / GaMaLib C++ Library.
@@ -20,13 +20,14 @@
 */
 
 /*
- *  $Id: adjusted_observations.h,v 1.5 2003/07/24 16:25:46 cepek Exp $
+ *  $Id: adjusted_observations.h,v 1.7 2004/03/18 17:07:01 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Vyrovnana_Pozorovani_h_
 #define GaMa_GaMaProg_Vyrovnana_Pozorovani_h_
 
 #include <gamalib/local/network.h>
+#include <gnu_gama/gon2deg.h>
 
 namespace GaMaLib {
 
@@ -37,9 +38,10 @@ void AdjustedObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
    using namespace GaMaLib;
    // using GaMaLib::Double;
 
-   const int y_sign = Consistent(IS->PD) ? +1 : -1;
-   const Vec& v = IS->residuals();
-   const int pocmer = IS->sum_observations();
+   const int    y_sign = Consistent(IS->PD) ? +1 : -1;
+   const Vec&   v      = IS->residuals();
+   const int    pocmer = IS->sum_observations();
+   const double scale  = IS->gons() ? 1.0 : 0.324;
 
    out << T_GaMa_adjobs_Adjusted_observations << "\n"
        << underline(T_GaMa_adjobs_Adjusted_observations, '*') << "\n\n";
@@ -86,7 +88,10 @@ void AdjustedObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
    {
      for (int i=minval; i<maxval; i++) out << "=";
    }
-   out << "==== [m|g] ====== [mm|cc] ==\n\n";
+   if (IS->gons())
+     out << "==== [m|g] ====== [mm|cc] ==\n\n";
+   else
+     out << "==== [m|d] ====== [mm|ss] ==\n\n";
    out.flush();
 
    PointID predcs = "";   // provious standpoint ID
@@ -125,12 +130,18 @@ void AdjustedObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
             out.precision(6);
             out.width(maxval);
             Double m = R2G*(s->value());
-            out << m << " ";
+            if (IS->gons())
+              out << m << " ";
+            else
+              out << GNU_gama::gon2deg(m, 0, 2) << " ";
             out.width(maxval);
             m += v(i)/10000;
             if (m < 0) m += 400;
             if (m >= 400) m -= 400;
-            out << m << " ";
+            if (IS->gons())
+              out << m << " ";
+            else
+              out << GNU_gama::gon2deg(m, 0, 2) << " ";
           }
         else if (Angle* u = dynamic_cast<Angle*>(pm))
           {
@@ -141,12 +152,18 @@ void AdjustedObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
             out.precision(6);
             out.width(maxval);
             Double m = R2G*(u->value());
-            out << m << " ";
+            if (IS->gons())
+              out << m << " ";
+            else
+              out << GNU_gama::gon2deg(m, 0, 2) << " ";
             out.width(maxval);
             m += v(i)/10000;
             if (m < 0) m += 400;
             if (m >= 400) m -= 400;
-            out << m << " ";
+            if (IS->gons())
+              out << m << " ";
+            else
+              out << GNU_gama::gon2deg(m, 0, 2) << " ";
           }
         else if (S_Distance* sd = dynamic_cast<S_Distance*>(pm))
           {
@@ -165,10 +182,16 @@ void AdjustedObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
             out.precision(6);
             out.width(maxval);
             Double m = R2G*(za->value());
-            out << m << " ";
+            if (IS->gons())
+              out << m << " ";
+            else
+              out << GNU_gama::gon2deg(m, 0, 2) << " ";
             out.width(maxval);
             m += v(i)/10000;
-            out << m << " ";
+            if (IS->gons())
+              out << m << " ";
+            else
+              out << GNU_gama::gon2deg(m, 0, 2) << " ";
           }
         else if (X* x = dynamic_cast<X*>(pm))
           {
@@ -257,6 +280,13 @@ void AdjustedObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
       out.precision(1);
       out.width(7);
       Double ml = IS->stdev_obs(i);
+      if (dynamic_cast<Direction*>(pm))
+        ml *= scale;
+      else if (dynamic_cast<Angle*>(pm))
+        ml *= scale;
+      else if (dynamic_cast<Z_Angle*>(pm))
+        ml *= scale;
+
       out << ml << " ";
       out.width(7);
       out << ml*kki;
