@@ -1,4 +1,4 @@
-/*  
+/*
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
     Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
 
@@ -20,14 +20,14 @@
 */
 
 /*
- *  $Id: error_ellipses.h,v 1.4 2003/06/14 15:00:22 cepek Exp $
+ *  $Id: error_ellipses.h,v 1.9 2004/04/19 18:41:08 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Prehled_Elipsy_Chyb_h_
 #define GaMa_GaMaProg_Prehled_Elipsy_Chyb_h_
 
 #include <gamalib/local/network.h>
-#include <gamalib/statan.h>
+#include <gnu_gama/statan.h>
 #include <cmath>
 
 namespace GaMaLib {
@@ -47,7 +47,7 @@ void ErrorEllipses(GaMaLib::LocalNetwork* IS, OutStream& out)
      Double alfa = (1 - IS->conf_pr());
      if (IS->m_0_apriori())
        {
-	 elp_k = sqrt(GaMaLib::Chi_square(float(alfa), 2));
+	 elp_k = sqrt(GNU_gama::Chi_square(float(alfa), 2));
        }
      else
        {
@@ -86,8 +86,12 @@ void ErrorEllipses(GaMaLib::LocalNetwork* IS, OutStream& out)
      out << T_GaMa_point << ' ';
      out << T_GaMa_errell_header1;
      for (int i=0; i<IS->maxw_id()+1; i++) out << '=';
-     out << T_GaMa_errell_header2
-	 << "\n\n";
+     if (IS->gons())
+       out << T_GaMa_errell_header2;
+     else
+       out <<
+         "== [mm] == [mm] ==== a [mm] b ==== [d] ===== a' [mm] b' ========";
+     out << "\n\n";
      {   // for ...
        // 1.3.13 for (int i=1; i<=pocnez; i++)
        // 1.3.13  if (IS->unknown_type(i) == 'X')
@@ -128,10 +132,10 @@ void ErrorEllipses(GaMaLib::LocalNetwork* IS, OutStream& out)
                
                Double a, b, alfa;
                IS->std_error_ellipse(point_id, a, b, alfa);
-               if (y_sign == -1)
-                 {
-                   alfa = 2*M_PI - alfa;
-                 }
+               // if (y_sign == -1)
+               //   {
+               //     // 1.7.10 alfa = 2*M_PI - alfa;
+               //   }
                out.width(7);
                if (a < 1000)     
                  out.setf(ios_base::fixed, ios_base::floatfield);
@@ -146,7 +150,9 @@ void ErrorEllipses(GaMaLib::LocalNetwork* IS, OutStream& out)
                out << b << ' ';
                out.width(7);
                out.setf(ios_base::fixed, ios_base::floatfield);
-               out << alfa*R2G << ' ';
+               double ea = alfa*R2G;
+               if (IS->degrees()) ea *= 360.0/400;
+               out << ea << ' ';
                
                if (mp < 1000 && mp > 1e-3)
                  {           // ********* testing noise (coordinates are OK)
