@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: residuals_observations.h,v 1.5 2003/06/14 15:00:22 cepek Exp $
+ *  $Id: residuals_observations.h,v 1.9 2004/04/19 18:41:08 cepek Exp $
  */
 
 
@@ -28,14 +28,14 @@
 #define GaMa_GaMaProg_Opravy_Pozorovani__h_
 
 #include <gamalib/local/network.h>
-#include <gamalib/statan.h>
+#include <gnu_gama/statan.h>
 #include <algorithm>
 #include <typeinfo>
 
 static float ResidualsObservations_N01(float x)   // local helper function
 {
    double D, f;
-   GaMaLib::NormalDistribution(double(x), D, f);
+   GNU_gama::NormalDistribution(double(x), D, f);
    return D;
 }
 
@@ -73,8 +73,10 @@ void ResidualsObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
   using namespace GaMaLib;
   using GaMaLib::Double;
 
-  const Vec& v = IS->residuals();
-  const int pocmer = IS->sum_observations();
+  const Vec&    v      = IS->residuals();
+  const int     pocmer = IS->sum_observations();
+  const double  scale  = IS->gons() ? 1.0 : 0.324;
+
   vector<int> odlehla;
   
   Double kki = IS->conf_int_coef();
@@ -125,7 +127,11 @@ void ResidualsObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
         for (int i=0; i < (IS->maxw_obs() + 2*(IS->maxw_id()) + 10); i++) 
           out << "=";
       }   // for ...
-      out << T_GaMa_resobs_header2;
+      // removed in 1.7.09 : out << T_GaMa_resobs_header2;
+      if (IS->gons())
+        out << "======== [mm|cc] =========== [mm|cc] ===\n\n";
+      else
+        out << "======== [mm|ss] =========== [mm|ss] ===\n\n";
       out.flush();
       
       
@@ -215,9 +221,17 @@ void ResidualsObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
           else            out << "  ";
           out << ' ';
           
+          double sc = 1.0;
+          if (dynamic_cast<Direction*>(pm))
+            sc = scale;
+          else if (dynamic_cast<Angle*>(pm))
+            sc = scale;
+          else if (dynamic_cast<Z_Angle*>(pm))
+            sc = scale;         
+    
           out.precision(3);
           out.width(9);
-          out << v(i) << ' ';
+          out << v(i)*sc << ' ';
           out.precision(1);
           out.width(4);
 
@@ -241,11 +255,11 @@ void ResidualsObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
                 {
                   Double em = v(i) / (IS->wcoef_res(i)*IS->weight_obs(i));
                   out.width(7);
-                  out << em;
+                  out << em*sc;
                   
                   Double ev = em - v(i);
                   out.width(7);
-                  out << ev;
+                  out << ev*sc;
                 }
             }
           
@@ -288,7 +302,8 @@ void ResidualsObservations(GaMaLib::LocalNetwork* IS, OutStream& out)
           for (int i=1; i<=pocmer; i++) pv(i) = (pv(i) - pvstr) / pvvar;
         
         float  ks, prob;
-        GaMaLib::KStest(pv.begin(), pocmer, ResidualsObservations_N01, ks, prob);
+        GNU_gama::KStest(pv.begin(), 
+                         pocmer, ResidualsObservations_N01, ks, prob);
         
         
         out.setf(ios_base::fixed, ios_base::floatfield);
