@@ -22,10 +22,10 @@
 */
 
 /*
- *  $Id: pointid.h,v 1.2 2003/05/11 12:32:25 cepek Exp $
+ *  $Id: pointid.h,v 1.4 2004/04/21 16:49:39 cepek Exp $
  */
 
-// PointID - point identification
+// PointID - point identification 
 
 #ifndef GaMaLib_Point_Identification__h
 #define GaMaLib_Point_Identification__h
@@ -98,7 +98,7 @@ namespace GaMaLib
         }
       
       #ifndef _MSC_VER
-      std::   /* one of ms improvements of C++ standard */
+      std::   
       #endif
            size_t length() const
         {
