@@ -20,23 +20,29 @@
 */
 
 /*
- *  $Id: gkfparser.cpp,v 1.10 2003/05/11 12:32:25 cepek Exp $
- */
+ *  $Id: gkfparser.cpp,v 1.15 2004/04/04 11:19:29 cepek Exp $
+ */ 
 
 
 #include <fstream>
 #include <string>
 #include <cstring>
 #include <cmath>
+#include <utility>
 
 #include <gamalib/xml/gkfparser.h>
 #include <gnu_gama/xml/encoding.h>
 #include <gamalib/observation.h>
 #include <gamalib/cluster.h>
-#include <gnu_gama/intfloat.h>
 #include <gamalib/language.h>
+#include <gnu_gama/intfloat.h>
+#include <gnu_gama/gon2deg.h>
 
 
+namespace {
+  typedef std::pair<double, bool> DB_pair;
+}
+
 using namespace std;
 namespace GaMaLib {
   
@@ -353,6 +359,7 @@ namespace GaMaLib {
     konf_pr         = 0.95;
     tol_abs         = 1000;
     typ_m0_apriorni = false;
+    update_constr   = false;
 
     state       = state_start;
     standpoint  = 0;
@@ -360,8 +367,11 @@ namespace GaMaLib {
     coordinates = 0;
     vectors     = 0;
 
+    obsolete_attribute = true;
+
     // throw exception if a covariance matrix is not positive-definite
     check_cov_mat = true;  
+
   }
 
 
@@ -492,6 +502,14 @@ namespace GaMaLib {
             else 
               return error(T_GKF_wrong_type_of_standard_deviation);
           }
+        else if (jmeno == "update-constrained-coordinates")
+          {
+            if      (hodnota == "yes") update_constr = true;
+            else if (hodnota == "no" ) update_constr = false;
+            else
+            return error(T_GKF_bad_network_configuration_unknown_parameter
+                         + jmeno + " = " + hodnota);
+          }
         else
           {
             return error(T_GKF_bad_network_configuration_unknown_parameter
@@ -510,7 +528,7 @@ namespace GaMaLib {
     // on reaching end tag </points-observations> this state is
     // ignored
 
-    string nam, val, sds_abc, sds, sdk, sde, ss="0", su="0"; 
+    string nam, val, sds_abc, sds, sdk, sde, ss="0", su="0", sz="0"; 
     state = state_point_obs;
 
     while (*atts)
@@ -533,8 +551,9 @@ namespace GaMaLib {
             if (i != val.end())
               return error(T_GKF_bad_attribute_distance_dev + sds_abc);
           }
-        else if (nam == "direction-stdev") ss = val;
-        else if (nam == "angle-stdev"    ) su = val;
+        else if (nam == "direction-stdev"   ) ss = val;
+        else if (nam == "angle-stdev"       ) su = val;
+        else if (nam == "zenith-angle-stdev") sz = val;
         else 
           return error(T_GKF_undefined_attribute_of_points_observations
                        + nam + " = " + val);
@@ -551,6 +570,8 @@ namespace GaMaLib {
       return error(T_GKF_bad_attribute_direction_dev + ss );
     if (!toDouble(su, uhel_str)) 
       return error(T_GKF_bad_attribute_angle_dev     + su );
+    if (!toDouble(sz, z_uhel_str)) 
+      return error(T_GKF_bad_attribute_angle_dev     + sz );
 
     return 0;
   }
@@ -574,14 +595,26 @@ namespace GaMaLib {
         else if (nam == "z"  ) sv = val;
         else if (nam == "fix") sf = val;
         else if (nam == "adj") sa = val;
-        else if (nam == "xy") st = val;          // ###### obsoleted
+        else if (nam == "xy" ) st = val;         // ###### obsoleted
         else if (nam == "height") sh = val;      // ###### obsoleted
         else 
-          return error(T_GKF_undefined_attribute_of_points + nam + " = " + val);
-        if (nam == "xy")          
-          description += "**** you are using obsolete XML attribute "+val+"\n";
-        else if (nam == "height") 
-          description += "**** you are using obsolete XML attribute "+val+"\n";
+          return 
+            error(T_GKF_undefined_attribute_of_points + nam + " = " + val);
+
+        if ((nam == "xy" || nam == "height") && obsolete_attribute)          
+          {
+            description += "\n**** Warning: ";
+            description += "obsolete XML attribute(s)";
+            description += "   <point ...";
+            description += " " + nam + "=\"" + val + "\" />\n";
+
+            ostringstream ostr;
+            ostr << "****          see line number " 
+                 << XML_GetCurrentLineNumber(parser) << "\n";;
+            description += ostr.str();
+
+            obsolete_attribute = false;
+          }
       }
 
     if (pp_id == "") return error(T_GKF_missing_point_ID);
@@ -660,24 +693,6 @@ namespace GaMaLib {
     else if (sh != "")
       return error(T_GKF_undefined_height_type + sh);
 
-    if      (st == "fixed"     )  
-      description += "**** you are using obsolete XML tags\n"; 
-    else if (st == "free"      )  
-      description += "**** you are using obsolete XML tags\n";
-    else if (st =="constrained")  
-      description += "**** you are using obsolete XML tags\n";
-    else if (st == "unused"    )  
-      description += "**** you are using obsolete XML tags\n";
-                                  
-    if      (sh == "fixed" )      
-      description += "**** you are using obsolete XML tags\n";
-    else if (sh == "free"  )      
-      description += "**** you are using obsolete XML tags\n";
-    else if (sh == "unused")      
-      description += "**** you are using obsolete XML tags\n";
-
-    // ################
-
     return 0;
   }
 
@@ -731,7 +746,7 @@ namespace GaMaLib {
         d->set_from_dh(df);
         d->set_to_dh(dt);
         standpoint->observation_list.push_back( d );
-        sigma.push_back(dv);
+        sigma.push_back(DB_pair(dv, false));
       } 
     catch (const /*GaMaLib::*/Exception &e) 
       {
@@ -745,6 +760,7 @@ namespace GaMaLib {
 
   int GKFparser::process_angle(const char** atts)
   {
+    bool degrees = false;
     string nam, val, ss=standpoint_id, sl, sp, sm, sv, hf, ht, h2;
     state = state_obs_angle;
 
@@ -773,7 +789,11 @@ namespace GaMaLib {
     if (sm == "") return error(T_GKF_missing_observed_value);
 
     double dm;
-    if (!toDouble(sm, dm)) return error(T_GKF_bad_angle + sm);
+    if (GNU_gama::deg2gon(sm, dm))
+      degrees = true;
+    else
+      if (!toDouble(sm, dm)) return error(T_GKF_bad_angle + sm);
+
     double dv = implicit_stdev_angle();
     if (sv != "")
       if (!toDouble(sv, dv)) return error(T_GKF_illegal_standard_deviation);
@@ -801,7 +821,7 @@ namespace GaMaLib {
         d->set_from_dh(df);
         d->set_to_dh(dt);
         standpoint->observation_list.push_back( d );
-        sigma.push_back(dv);
+        sigma.push_back(DB_pair(dv, degrees));
       } 
     catch (const /*GaMaLib::*/Exception &e) 
       {
@@ -861,7 +881,7 @@ namespace GaMaLib {
         d->set_from_dh(df);
         d->set_to_dh(dt);
         standpoint->observation_list.push_back( d );
-        sigma.push_back(dv);
+        sigma.push_back(DB_pair(dv, false));
       } 
     catch (const /*GaMaLib::*/Exception &e) 
       {
@@ -875,6 +895,7 @@ namespace GaMaLib {
 
   int GKFparser::process_zangle(const char** atts)
   {
+    bool degrees = false;
     string nam, val, ss=standpoint_id, sc, sm, sv, hf, ht;
     state = state_obs_zangle;
 
@@ -896,8 +917,12 @@ namespace GaMaLib {
     if (sm == "") return error(T_GKF_missing_observed_value);
 
     double dm;
-    if (!toDouble(sm, dm)) return error(T_GKF_bad_distance + sm);
-    double dv = implicit_stdev_distance(dm);
+    if (GNU_gama::deg2gon(sm, dm))
+      degrees = true;
+    else
+      if (!toDouble(sm, dm)) return error(T_GKF_bad_zangle + sm);
+
+    double dv = implicit_stdev_zangle();
     if (sv != "")
       if (!toDouble(sv, dv)) return error(T_GKF_illegal_standard_deviation);
     double df = obs_from_dh;
@@ -920,7 +945,7 @@ namespace GaMaLib {
         d->set_from_dh(df);
         d->set_to_dh(dt);
         standpoint->observation_list.push_back( d );
-        sigma.push_back(dv);
+        sigma.push_back(DB_pair(dv, degrees));
       } 
     catch (const /*GaMaLib::*/Exception &e) 
       {
@@ -982,15 +1007,23 @@ namespace GaMaLib {
         const Index N = sigma.size();
         standpoint->covariance_matrix.reset(N, 0);
         Cov::iterator c=standpoint->covariance_matrix.begin();
-        std::vector<Double>::iterator s = sigma.begin();
+        std::vector<DB_pair>::iterator s = sigma.begin();
 
-        for (Index i=1; i<=N; ++i, ++c, ++s) *c = (*s) * (*s);
+        for (Index i=1; i<=N; ++i, ++c, ++s) *c = (*s).first * (*s).first;
       }
 
     if (check_cov_mat) 
       {
         try 
           {
+            // scaling of rows/columns corresponding to covariances
+            // given in sexagesimal seconds
+            std::vector<DB_pair>::iterator s = sigma.begin();
+            for (Index i=1; i<=sigma.size(); ++i, ++s)
+              {
+                if ((*s).second) standpoint->scaleCov(i, 1.0/0.324);
+              }
+
             Cov tmp = standpoint->covariance_matrix;
             tmp.cholDec();
           }
@@ -1010,6 +1043,7 @@ namespace GaMaLib {
 
   int GKFparser::process_direction(const char** atts)
   {
+    bool degrees = false;
     string nam, val, sc, sm, ss, hf, ht;
     state = state_obs_direction;
 
@@ -1032,7 +1066,11 @@ namespace GaMaLib {
     if (sm   == "") return error(T_GKF_missing_observed_value);
 
     double dm;
-    if (!toDouble(sm, dm)) return error(T_GKF_bad_direction + sm);
+    if (GNU_gama::deg2gon(sm, dm))
+      degrees = true;
+    else
+      if (!toDouble(sm, dm)) return error(T_GKF_bad_direction + sm);
+
     double ds = implicit_stdev_direction();
     if (ss != "")
       if (!toDouble(ss, ds)) return error(T_GKF_illegal_standard_deviation);
@@ -1051,7 +1089,7 @@ namespace GaMaLib {
         d->set_from_dh(df);
         d->set_to_dh(dt);
         standpoint->observation_list.push_back( d );
-        sigma.push_back(ds);
+        sigma.push_back(DB_pair(ds, degrees));
       } 
     catch (const /*GaMaLib::*/Exception &e) 
       {
@@ -1106,7 +1144,7 @@ namespace GaMaLib {
         H_Diff* hd = new H_Diff(sfrom, sto, dm, dd);
         // ###### heightdifferences->observation_list.push_back( hd );
         standpoint->observation_list.push_back( hd );
-        sigma.push_back(ds);
+        sigma.push_back(DB_pair(ds, false));
       }
     catch  (const /*GaMaLib::*/Exception &e) 
       {
@@ -1288,9 +1326,9 @@ namespace GaMaLib {
         const Index N = sigma.size();
         heightdifferences->covariance_matrix.reset(N, 0);
         Cov::iterator c=heightdifferences->covariance_matrix.begin();
-        std::vector<Double>::iterator s = sigma.begin();
+        std::vector<DB_pair>::iterator s = sigma.begin();
 
-        for (Index i=1; i<=N; ++i, ++c, ++s) *c = (*s) * (*s);
+        for (Index i=1; i<=N; ++i, ++c, ++s) *c = (*s).first * (*s).first;
       }
 
     if (check_cov_mat) 
@@ -1350,7 +1388,7 @@ namespace GaMaLib {
       {
         H_Diff* hd = new H_Diff(sfrom, sto, dm, dd);
         heightdifferences->observation_list.push_back( hd );
-        sigma.push_back(ds);
+        sigma.push_back(DB_pair(ds, false));
       }
     catch  (const /*GaMaLib::*/Exception &e) 
       {
