@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: gkfparser.h,v 1.10 2003/05/11 12:32:25 cepek Exp $
+ *  $Id: gkfparser.h,v 1.13 2004/04/03 11:06:37 cepek Exp $
  */
 
 #ifndef GaMaLib_GKF__XML__parser__h_
@@ -68,9 +68,11 @@ namespace GaMaLib {
       std::string   TXT, STX, OPR;      // file names from gkf specification
       double m0_apr, konf_pr, tol_abs;  // implicitly 10, 0.95, 1000
       bool   typ_m0_apriorni;           // implicitly false
+      bool   update_constr;             // implicitly false
       
       double implicit_stdev_direction() const { return smer_str; }
-      double implicit_stdev_angle() const { return uhel_str; }
+      double implicit_stdev_angle()    const { return uhel_str; }
+      double implicit_stdev_zangle()   const { return z_uhel_str; }
       double implicit_stdev_distance(double d) const 
         { 
           using namespace std;
@@ -145,7 +147,8 @@ namespace GaMaLib {
         state_stop
       };
       
-      std::vector<Double> sigma;
+      // 1.7.09 std::pair<"standard deviation", "angular value in degrees">
+      std::vector<std::pair<Double, bool> > sigma;
       Index        idim, iband;            // covariance matrix dim. / band
       bool         pp_xydef, pp_zdef;      // process_point();
       Double       pp_x, pp_y, pp_z;
@@ -222,6 +225,11 @@ namespace GaMaLib {
       double delka_str_exp;
       double smer_str;
       double uhel_str;
+      double z_uhel_str;
+
+      // obsolete XML tags and attributes -- warning messages
+
+      bool  obsolete_attribute;
       
     };  // class GKFparser
 }       // namespace GaMaLib
