@@ -1,8 +1,8 @@
 /*  
-    GNU GaMa / C++ GaMaLib Library
-    Copyright (C) 1999, 2002  Ales Cepek <cepek@fsv.cvut.cz>
+    GNU Gama C++ library
+    Copyright (C) 1999, 2002, 2003  Ales Cepek <cepek@fsv.cvut.cz>
 
-    This file is part of the GNU GaMa / C++ GaMaLib library.
+    This file is part of the GNU Gama C++ library.
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,14 +20,16 @@
 */
 
 /*
- *  $Id: gama-local-main.h,v 1.5 2003/01/20 17:57:17 cepek Exp $
+ *  $Id: gama-local-main.h,v 1.17 2004/05/01 13:56:31 cepek Exp $
  */
 
 #ifndef GAMA_MAIN__gama_main__gm_mn__g_m__g______________________________h___
 #define GAMA_MAIN__gama_main__gm_mn__g_m__g______________________________h___
 
+#include <gnu_gama/outstream.h>
+
 #include <cstring>
-#include <gamalib/version.h>
+#include <gnu_gama/version.h>
 #include <gamalib/language.h>
 #include <gamalib/local/gamadata.h>
 #include <gamalib/xml/gkfparser.h>
@@ -65,8 +67,8 @@ int help()
   
   cerr << "\n" 
        << "Adjustment of local geodetic network"
-       << "        version: "<< GaMaLib_version
-       << " / " << GaMaLib_compiler << "\n"
+       << "        version: "<< GNU_gama::GNU_gama_version
+       << " / " << GNU_gama::GNU_gama_compiler << "\n"
        << "************************************\n"
        << "http://www.gnu.org/software/gama/\n\n"
        << "Usage: " << /*argv[0]*/"gama-local" 
@@ -75,10 +77,12 @@ int help()
        << " [ output. ]\n\n";
   cerr << "Options:\n"
        << "\n";
-  cerr << "--algorithm svd|gso     \n" 
-       << "--language  en|cz|fi|du \n"
-       << "--version               \n"
-       << "--help              this text\n";
+  cerr << "--algorithm  svd | gso\n" 
+       << "--language   en | ca | cz | du | fi | hu\n"
+       << "--encoding   utf-8 | iso-8859-2 | iso-8859-2-flat | cp-1250\n"
+       << "--angles     400 | 360\n"  
+       << "--version\n"
+       << "--help\n";
   cerr << endl;
   return 1;
 }
@@ -89,7 +93,7 @@ int version()
   using namespace std;
   using namespace GaMaLib;
   
-  cout << GaMaLib_version << endl;
+  cout << GNU_gama::GNU_gama_version << endl;
 
   return 0;
 }
@@ -106,6 +110,8 @@ int GaMa_Main(int argc, char **argv)
   const char* argv_2 = 0;
   const char* argv_algo = 0;
   const char* argv_lang = 0;
+  const char* argv_enc  = 0;
+  const char* argv_angles = 0;
 
   for (int i=1; i<argc; i++)
     {
@@ -135,6 +141,8 @@ int GaMa_Main(int argc, char **argv)
       else if ( i   ==  argc      ) return help();
       else if (name == "algorithm") argv_algo = c; 
       else if (name == "language" ) argv_lang = c;
+      else if (name == "encoding" ) argv_enc  = c;
+      else if (name == "angles"   ) argv_angles = c;
       else
         return help();
     }
@@ -145,16 +153,35 @@ int GaMa_Main(int argc, char **argv)
   else
     {
       if (!strcmp("en", argv_lang)) set_gama_language(en);
+      else if (!strcmp("ca", argv_lang)) set_gama_language(ca);
       else if (!strcmp("cs", argv_lang)) set_gama_language(cz);
       else if (!strcmp("cz", argv_lang)) set_gama_language(cz);
-      else if (!strcmp("fi", argv_lang)) set_gama_language(fi);
       else if (!strcmp("du", argv_lang)) set_gama_language(du);
+      else if (!strcmp("fi", argv_lang)) set_gama_language(fi);
+      else if (!strcmp("hu", argv_lang)) set_gama_language(hu);
       else return help();
     }
 
   LocalNetwork* IS;
-  ofstream cout;
+  ofstream fcout;
+  GNU_gama::OutStream cout(fcout);
   
+  if (argv_enc)
+    {
+      using namespace GNU_gama;
+
+      if (!strcmp("utf-8", argv_enc)) 
+        cout.set_encoding(OutStream::utf_8);
+      else if (!strcmp("iso-8859-2", argv_enc)) 
+        cout.set_encoding(OutStream::iso_8859_2);
+      else if (!strcmp("iso-8859-2-flat", argv_enc)) 
+        cout.set_encoding(OutStream::iso_8859_2_flat);
+      else if (!strcmp("cp-1250", argv_enc)) 
+        cout.set_encoding(OutStream::cp_1250);
+      else
+        return help();
+    }
+
   try {
     
     try {
@@ -169,6 +196,16 @@ int GaMa_Main(int argc, char **argv)
         else return help();
       }
 
+      if (argv_angles)
+        {
+          if (!strcmp("400", argv_angles))
+            IS->set_gons();
+          else if (!strcmp("360", argv_angles))
+            IS->set_degrees();
+          else
+            return help();
+        }
+
     }
     catch (...) {
       throw 
@@ -248,7 +285,10 @@ int GaMa_Main(int argc, char **argv)
           IS->apriori_m_0(gkf.m0_apr );
           IS->conf_pr    (gkf.konf_pr);
           IS->tol_abs    (gkf.tol_abs);
-          
+
+          // added in 1.7.09
+          IS->update_constrained_coordinates(gkf.update_constr);
+ 
           if (gkf.typ_m0_apriorni)
             IS->set_m_0_apriori();
           else
@@ -283,13 +323,13 @@ int GaMa_Main(int argc, char **argv)
       }
     
     if (file_txt == "")  file_txt = string(argv_1) 
-                          + "-" + string(GaMaLib_version)
+                          + "-" + string(GNU_gama::GNU_gama_version)
                           + "-" + string(IS->algorithm());
 
-    cout.open(file_txt.c_str());
+    fcout.open(file_txt.c_str());
     
   }
-  catch (const ParserException& v) {
+  catch (const GaMaLib::ParserException& v) {
     cerr << "\n" << T_GaMa_exception_2a << "\n\n"
          << T_GaMa_exception_2b << v.line << " : " << v.text << endl;
     return 3;      
@@ -311,8 +351,9 @@ int GaMa_Main(int argc, char **argv)
     
     {
       cout << T_GaMa_Adjustment_of_geodetic_network << "        "
-           << T_GaMa_version << GaMaLib_version << "-" << IS->algorithm()
-           << " / " << GaMaLib_compiler << "\n"
+           << T_GaMa_version << GNU_gama::GNU_gama_version 
+           << "-" << IS->algorithm()
+           << " / " << GNU_gama::GNU_gama_compiler << "\n"
            << underline(T_GaMa_Adjustment_of_geodetic_network, '*') << "\n"
            << "http://www.gnu.org/software/gama/\n\n\n";
     }
@@ -325,7 +366,7 @@ int GaMa_Main(int argc, char **argv)
     
     try
       {
-        if (!Consistent(IS->PD, IS->OD))
+        if (!Consistent(IS->PD))
           {
             cout << T_GaMa_inconsistent_coordinates_and_angles << "\n\n\n";
           }
@@ -356,12 +397,6 @@ int GaMa_Main(int argc, char **argv)
                  << "\n\n\n";
           }
 
-        if (file_opr != "")
-          {
-            ofstream opr(file_opr.c_str());
-            IS->project_equations(opr);
-          }
-        
         NetworkDescription(description, cout);
         if (GeneralParameters(IS, cout))
           {
@@ -391,6 +426,12 @@ int GaMa_Main(int argc, char **argv)
 
           }
         
+        if (file_opr != "")
+          {
+            ofstream opr(file_opr.c_str());
+            IS->project_equations(opr);
+          }
+        
         if (xml_output != "")
           {
             ofstream xml(xml_output.c_str());
