@@ -1,5 +1,5 @@
 /*  
-    C++ Matrix/Vector templates (GNU GaMa / gMatVec 0.9.21)
+    C++ Matrix/Vector templates (GNU Gama / gMatVec 0.9.22)
     Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
 
     This file is part of the gMatVec C++ Matrix/Vector template library.
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: sortvec.h,v 1.8 2002/11/14 14:58:52 cepek Exp $
+ *  $Id: sortvec.h,v 1.10 2003/08/14 16:20:25 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -36,8 +36,8 @@ namespace gMatVec {
 template <class Float, class Exc>
 inline void sort(Vec<Float, Exc>& v)
   {
-    Vec<Float, Exc>::iterator b = v.begin();
-    Vec<Float, Exc>::iterator e = v.end();
+    typename Vec<Float, Exc>::iterator b = v.begin();
+    typename Vec<Float, Exc>::iterator e = v.end();
     std::sort(b, e);
   }
 
