@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_model.cpp,v 1.26 2004/02/20 20:34:25 cepek Exp $
+ *  $Id: g3_model.cpp,v 1.29 2004/05/17 16:20:25 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_model.h>
@@ -146,9 +146,13 @@ void Model::write_xml(std::ostream& out) const
 
 void Model::update_index(Parameter& p)
 {
-  if (!p.index()) 
+  if (!p.has_index()) 
     {
-      p.set_index(++dm_cols);
+      if (p.free())
+        p.set_index(++dm_cols);
+      else
+        p.set_index(1);
+
       par_list->push_back(&p);
     }
 }
@@ -169,48 +173,48 @@ void Model::update_parameters()
     {
       Point* point = (*i);
  
-      point->N_.set_index(0);
-      point->E_.set_index(0);
-      point->U_.set_index(0);
+      point->N.set_index(0);
+      point->E.set_index(0);
+      point->U.set_index(0);
 
 
       if (point->fixed_horizontal_position())
         {
-          point->N_.set_fixed();
-          point->E_.set_fixed();
+          point->N.set_fixed();
+          point->E.set_fixed();
         }
       else if (point->constr_horizontal_position())
         {
-          point->N_.set_constr();
-          point->E_.set_constr();
+          point->N.set_constr();
+          point->E.set_constr();
         }
       else if (point->free_horizontal_position())
         {
-          point->N_.set_free();
-          point->E_.set_free();
+          point->N.set_free();
+          point->E.set_free();
         }
       else
         {
-          point->N_.set_unused();
-          point->E_.set_unused();
+          point->N.set_unused();
+          point->E.set_unused();
         }
       
 
       if (point->fixed_height())
         {
-          point->U_.set_fixed();
+          point->U.set_fixed();
         }
       else if (point->constr_height())
         {
-          point->U_.set_constr();
+          point->U.set_constr();
         }
       else if (point->free_height())
         {
-          point->U_.set_free();
+          point->U.set_free();
         }
       else
         {
-          point->U_.set_unused();
+          point->U.set_unused();
         }
     }
 
@@ -323,6 +327,25 @@ void Model::update_linearization()
 }
 
 
+void Model::update_adjustment()
+{
+  cerr << "\n************ void Model::update_adjustment()\n\n";
+  if (!check_linearization()) update_linearization();
+
+  cerr << "x() = " << adj->x();
+  for (ParameterList::iterator 
+         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
+    {
+      Parameter* p = *i;
+      if (int k = p->index()) p->set_correction(adj->x()(k));
+    }
+  
+
+  cerr << "\n------------ void Model::update_adjustment()\n\n";
+  return next_state_(adjust_);
+}
+
+
 void Model::write_xml_adjustment_input_data(std::ostream& out)
 {
   if (!check_linearization()) update_linearization();
@@ -333,13 +356,60 @@ void Model::write_xml_adjustment_input_data(std::ostream& out)
 }
 
 
-void Model::update_adjustment()
+void Model::write_xml_adjustment_results(std::ostream& out)
 {
-  cerr << "\n************ void Model::update_adjustment()\n\n";
-  if (!check_linearization()) update_linearization();
+  if (!check_adjustment()) update_adjustment();
 
-  cerr << "x() = " << adj->x();
+  out << 
+    "\n<!-- adjustment results  :"
+    " dn / de / du  are in millimeters -->\n\n";
+  
+  out << "<adjustment-results>\n";
 
-  cerr << "\n------------ void Model::update_adjustment()\n\n";
-  return next_state_(adjust_);
+  for (ParameterList::iterator 
+         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
+    {
+      (*i)->write_xml_init();
+    }
+  for (ParameterList::iterator 
+         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
+    {
+      (*i)->write_xml(out);
+    }
+  
+  out << "\n</adjustment-results>\n";
 }
+
+
+GNU_gama::E_3 Model::vector(const Point* from, const Point* to) const
+{
+  GNU_gama::E_3 v;
+  
+  v.set(to  ->X(), to  ->Y(), to  ->Z());
+  v.sub(from->X(), from->Y(), from->Z());
+
+  return v;
+}
+
+
+GNU_gama::E_3 Model::normal(const Point* p) const
+{
+  const double B = p->B();
+  const double L = p->L();
+
+  return GNU_gama::E_3(std::cos(B)*std::cos(L),
+                       std::cos(B)*std::sin(L),
+                       std::sin(B)            );
+}
+
+
+GNU_gama::E_3 Model::vertical(const Point* p) const
+{
+  const double B = p->B() + p->dB();
+  const double L = p->L() + p->dL();
+
+  return GNU_gama::E_3(std::cos(B)*std::cos(L),
+                       std::cos(B)*std::sin(L),
+                       std::sin(B)            );
+}
+
