@@ -20,9 +20,12 @@
 */
 
 /*
- *  $Id: g3_model.h,v 1.22 2004/02/22 11:59:46 cepek Exp $
+ *  $Id: g3_model.h,v 1.25 2004/05/17 16:20:25 cepek Exp $
  */
 
+#ifndef GNU_gama__g3_model_h_gnugamag3modelh___gnu_gama_g3model
+#define GNU_gama__g3_model_h_gnugamag3modelh___gnu_gama_g3model
+
 #include <gnu_gama/model.h>
 #include <gnu_gama/pointbase.h>
 #include <gnu_gama/obsdata.h>
@@ -33,22 +36,20 @@
 #include <gnu_gama/sparse/smatrix.h>
 #include <gnu_gama/sparse/sbdiagonal.h>
 #include <gnu_gama/adj/adj.h>
-
-#ifndef GNU_gama__g3_model_h_gnugamag3modelh___gnu_gama_g3model
-#define GNU_gama__g3_model_h_gnugamag3modelh___gnu_gama_g3model
-
+#include <gnu_gama/e3.h>
 
 namespace GNU_gama {  namespace g3 {
 
-  
-  class Model : 
+    class Model : 
     public GNU_gama::Model<g3::Observation>,
     public Revision     <Distance>,
     public Linearization<Distance>,
     public Revision     <Vector>,
     public Linearization<Vector>,
     public Revision     <XYZ>,
-    public Linearization<XYZ>
+    public Linearization<XYZ>,
+    public Revision     <ZenithAngle>,
+    public Linearization<ZenithAngle>
   {
   public:
     
@@ -85,14 +86,21 @@ namespace GNU_gama {  namespace g3 {
     void update_linearization();
     void update_adjustment();
         
-    bool revision_visit     (Distance*);
-    void linearization_visit(Distance*);
-    bool revision_visit     (Vector*  );
-    void linearization_visit(Vector*  );
-    bool revision_visit     (XYZ*     );
-    void linearization_visit(XYZ*     );
+    bool revision_visit     (Distance*   );
+    void linearization_visit(Distance*   );
+    bool revision_visit     (Vector*     );
+    void linearization_visit(Vector*     );
+    bool revision_visit     (XYZ*        );
+    void linearization_visit(XYZ*        );
+    bool revision_visit     (ZenithAngle*);
+    void linearization_visit(ZenithAngle*);
 
     void write_xml_adjustment_input_data(std::ostream&);
+    void write_xml_adjustment_results   (std::ostream&);
+
+    GNU_gama::E_3 vector  (const Point* from, const Point* to) const;
+    GNU_gama::E_3 normal  (const Point* p) const;
+    GNU_gama::E_3 vertical(const Point* p) const;
 
   private:   /*-----------------------------------------------------------*/
       
