@@ -20,10 +20,10 @@
 */
 
 /*
- *  $Id: g3_point.h,v 1.23 2004/01/26 19:03:09 cepek Exp $
+ *  $Id: g3_point.h,v 1.26 2004/04/23 22:01:31 cepek Exp $
  */
 
-#include <gamalib/pointid.h>
+#include <string>
 #include <gnu_gama/g3/g3_parameter.h>
 
 #ifndef GNU_gama__g3_point_h_gnugamag3pointh___gnu_gama_g3point
@@ -34,19 +34,22 @@ namespace GNU_gama {  namespace g3 {
 
   class Model;
 
-  class Point {
+  class Point : public ParXML {
   public:
   
-    typedef GaMaLib::PointID Name;
-    typedef Model            Common;
+    typedef std::string   Name;
+    typedef Model         Common;
 
     Name    name;
     Common* common; 
 
-    const Parameter& N;
-    const Parameter& E;
-    const Parameter& U;
-    const Parameter& height;
+    Parameter N;
+    Parameter E;
+    Parameter U;
+    Parameter height;
+    Parameter geoid;
+    Parameter dB;
+    Parameter dL;
 
     const Parameter& B;
     const Parameter& L;
@@ -95,6 +98,8 @@ namespace GNU_gama {  namespace g3 {
     double Y_dh(double dh) const { return Y() + r23*dh; }
     double Z_dh(double dh) const { return Z() + r33*dh; }
 
+    void write_xml(std::ostream&);
+
   private:
 
     double x_transform(double n, double e, double u);
@@ -123,7 +128,6 @@ namespace GNU_gama {  namespace g3 {
     };
 
     friend class Model;
-    Parameter  N_, E_, U_, height_;
     Parameter  B_, L_, H_, X_, Y_, Z_;
 
     void point_copy(const Point&);
